@@ -37,36 +37,36 @@ use lib "$Bin/../../lib";
 use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
 use Google::Ads::GoogleAds::Utils::MediaUtils;
-use Google::Ads::GoogleAds::V9::Resources::CampaignBudget;
-use Google::Ads::GoogleAds::V9::Resources::Campaign;
-use Google::Ads::GoogleAds::V9::Resources::CampaignCriterion;
-use Google::Ads::GoogleAds::V9::Resources::Asset;
-use Google::Ads::GoogleAds::V9::Resources::AssetGroup;
-use Google::Ads::GoogleAds::V9::Resources::AssetGroupAsset;
-use Google::Ads::GoogleAds::V9::Common::MaximizeConversionValue;
-use Google::Ads::GoogleAds::V9::Common::LocationInfo;
-use Google::Ads::GoogleAds::V9::Common::LanguageInfo;
-use Google::Ads::GoogleAds::V9::Common::TextAsset;
-use Google::Ads::GoogleAds::V9::Common::ImageAsset;
-use Google::Ads::GoogleAds::V9::Enums::BudgetDeliveryMethodEnum qw(STANDARD);
-use Google::Ads::GoogleAds::V9::Enums::CampaignStatusEnum;
-use Google::Ads::GoogleAds::V9::Enums::AdvertisingChannelTypeEnum
+use Google::Ads::GoogleAds::V10::Resources::CampaignBudget;
+use Google::Ads::GoogleAds::V10::Resources::Campaign;
+use Google::Ads::GoogleAds::V10::Resources::CampaignCriterion;
+use Google::Ads::GoogleAds::V10::Resources::Asset;
+use Google::Ads::GoogleAds::V10::Resources::AssetGroup;
+use Google::Ads::GoogleAds::V10::Resources::AssetGroupAsset;
+use Google::Ads::GoogleAds::V10::Common::MaximizeConversionValue;
+use Google::Ads::GoogleAds::V10::Common::LocationInfo;
+use Google::Ads::GoogleAds::V10::Common::LanguageInfo;
+use Google::Ads::GoogleAds::V10::Common::TextAsset;
+use Google::Ads::GoogleAds::V10::Common::ImageAsset;
+use Google::Ads::GoogleAds::V10::Enums::BudgetDeliveryMethodEnum qw(STANDARD);
+use Google::Ads::GoogleAds::V10::Enums::CampaignStatusEnum;
+use Google::Ads::GoogleAds::V10::Enums::AdvertisingChannelTypeEnum
   qw(PERFORMANCE_MAX);
-use Google::Ads::GoogleAds::V9::Enums::AssetGroupStatusEnum;
-use Google::Ads::GoogleAds::V9::Enums::AssetFieldTypeEnum
+use Google::Ads::GoogleAds::V10::Enums::AssetGroupStatusEnum;
+use Google::Ads::GoogleAds::V10::Enums::AssetFieldTypeEnum
   qw(HEADLINE DESCRIPTION LONG_HEADLINE BUSINESS_NAME LOGO MARKETING_IMAGE SQUARE_MARKETING_IMAGE);
-use Google::Ads::GoogleAds::V9::Services::GoogleAdsService::MutateOperation;
+use Google::Ads::GoogleAds::V10::Services::GoogleAdsService::MutateOperation;
 use
-  Google::Ads::GoogleAds::V9::Services::CampaignBudgetService::CampaignBudgetOperation;
-use Google::Ads::GoogleAds::V9::Services::CampaignService::CampaignOperation;
+  Google::Ads::GoogleAds::V10::Services::CampaignBudgetService::CampaignBudgetOperation;
+use Google::Ads::GoogleAds::V10::Services::CampaignService::CampaignOperation;
 use
-  Google::Ads::GoogleAds::V9::Services::CampaignCriterionService::CampaignCriterionOperation;
-use Google::Ads::GoogleAds::V9::Services::AssetService::AssetOperation;
+  Google::Ads::GoogleAds::V10::Services::CampaignCriterionService::CampaignCriterionOperation;
+use Google::Ads::GoogleAds::V10::Services::AssetService::AssetOperation;
 use
-  Google::Ads::GoogleAds::V9::Services::AssetGroupService::AssetGroupOperation;
+  Google::Ads::GoogleAds::V10::Services::AssetGroupService::AssetGroupOperation;
 use
-  Google::Ads::GoogleAds::V9::Services::AssetGroupAssetService::AssetGroupAssetOperation;
-use Google::Ads::GoogleAds::V9::Utils::ResourceNames;
+  Google::Ads::GoogleAds::V10::Services::AssetGroupAssetService::AssetGroupAssetOperation;
+use Google::Ads::GoogleAds::V10::Utils::ResourceNames;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
@@ -160,16 +160,17 @@ sub create_campaign_budget_operation {
 
   # Create a mutate operation that creates a campaign budget operation.
   return
-    Google::Ads::GoogleAds::V9::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V10::Services::GoogleAdsService::MutateOperation->
     new({
       campaignBudgetOperation =>
-        Google::Ads::GoogleAds::V9::Services::CampaignBudgetService::CampaignBudgetOperation
+        Google::Ads::GoogleAds::V10::Services::CampaignBudgetService::CampaignBudgetOperation
         ->new({
-          create => Google::Ads::GoogleAds::V9::Resources::CampaignBudget->new({
+          create => Google::Ads::GoogleAds::V10::Resources::CampaignBudget->new(
+            {
               # Set a temporary ID in the budget's resource name so it can be
               # referenced by the campaign in later steps.
               resourceName =>
-                Google::Ads::GoogleAds::V9::Utils::ResourceNames::campaign_budget(
+                Google::Ads::GoogleAds::V10::Utils::ResourceNames::campaign_budget(
                 $customer_id, BUDGET_TEMPORARY_ID
                 ),
               name => "Performance Max campaign budget #" . uniqid(),
@@ -192,27 +193,27 @@ sub create_performance_max_campaign_operation {
 
   # Create a mutate operation that creates a campaign operation.
   return
-    Google::Ads::GoogleAds::V9::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V10::Services::GoogleAdsService::MutateOperation->
     new({
       campaignOperation =>
-        Google::Ads::GoogleAds::V9::Services::CampaignService::CampaignOperation
+        Google::Ads::GoogleAds::V10::Services::CampaignService::CampaignOperation
         ->new({
-          create => Google::Ads::GoogleAds::V9::Resources::Campaign->new({
+          create => Google::Ads::GoogleAds::V10::Resources::Campaign->new({
               # Assign the resource name with a temporary ID.
               resourceName =>
-                Google::Ads::GoogleAds::V9::Utils::ResourceNames::campaign(
+                Google::Ads::GoogleAds::V10::Utils::ResourceNames::campaign(
                 $customer_id, PERFORMANCE_MAX_CAMPAIGN_TEMPORARY_ID
                 ),
               name => "Performance Max campaign #" . uniqid(),
               # Set the budget using the given budget resource name.
               campaignBudget =>
-                Google::Ads::GoogleAds::V9::Utils::ResourceNames::campaign_budget(
+                Google::Ads::GoogleAds::V10::Utils::ResourceNames::campaign_budget(
                 $customer_id, BUDGET_TEMPORARY_ID
                 ),
               # Set the campaign status as PAUSED. The campaign is the only entity in
               # the mutate request that should have its status set.
               status =>
-                Google::Ads::GoogleAds::V9::Enums::CampaignStatusEnum::PAUSED,
+                Google::Ads::GoogleAds::V10::Enums::CampaignStatusEnum::PAUSED,
               # All Performance Max campaigns have an advertisingChannelType of
               # PERFORMANCE_MAX. The advertisingChannelSubType should not be set.
               advertisingChannelType => PERFORMANCE_MAX,
@@ -228,7 +229,7 @@ sub create_performance_max_campaign_operation {
               # article: http://support.google.com/google-ads/answer/7684216.
               # A targetRoas of 3.5 corresponds to a 350% return on ad spend.
               maximizeConversionValue =>
-                Google::Ads::GoogleAds::V9::Common::MaximizeConversionValue->
+                Google::Ads::GoogleAds::V10::Common::MaximizeConversionValue->
                 new({
                   targetRoas => 3.5
                 }
@@ -268,68 +269,68 @@ sub create_campaign_criterion_operations {
   # and one negative location target for Brooklyn (ID=1022762).
   # First, add the positive (negative = false) for New York City.
   push @$operations,
-    Google::Ads::GoogleAds::V9::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V10::Services::GoogleAdsService::MutateOperation->
     new({
       campaignCriterionOperation =>
-        Google::Ads::GoogleAds::V9::Services::CampaignCriterionService::CampaignCriterionOperation
+        Google::Ads::GoogleAds::V10::Services::CampaignCriterionService::CampaignCriterionOperation
         ->new({
           create =>
-            Google::Ads::GoogleAds::V9::Resources::CampaignCriterion->new({
+            Google::Ads::GoogleAds::V10::Resources::CampaignCriterion->new({
               campaign =>
-                Google::Ads::GoogleAds::V9::Utils::ResourceNames::campaign(
+                Google::Ads::GoogleAds::V10::Utils::ResourceNames::campaign(
                 $customer_id, PERFORMANCE_MAX_CAMPAIGN_TEMPORARY_ID
                 ),
-              location => Google::Ads::GoogleAds::V9::Common::LocationInfo->new(
-                {
+              location =>
+                Google::Ads::GoogleAds::V10::Common::LocationInfo->new({
                   geoTargetConstant =>
-                    Google::Ads::GoogleAds::V9::Utils::ResourceNames::geo_target_constant(
+                    Google::Ads::GoogleAds::V10::Utils::ResourceNames::geo_target_constant(
                     1023191)}
-              ),
+                ),
               negative => "false"
             })})});
 
   # Next add the negative target for Brooklyn.
   push @$operations,
-    Google::Ads::GoogleAds::V9::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V10::Services::GoogleAdsService::MutateOperation->
     new({
       campaignCriterionOperation =>
-        Google::Ads::GoogleAds::V9::Services::CampaignCriterionService::CampaignCriterionOperation
+        Google::Ads::GoogleAds::V10::Services::CampaignCriterionService::CampaignCriterionOperation
         ->new({
           create =>
-            Google::Ads::GoogleAds::V9::Resources::CampaignCriterion->new({
+            Google::Ads::GoogleAds::V10::Resources::CampaignCriterion->new({
               campaign =>
-                Google::Ads::GoogleAds::V9::Utils::ResourceNames::campaign(
+                Google::Ads::GoogleAds::V10::Utils::ResourceNames::campaign(
                 $customer_id, PERFORMANCE_MAX_CAMPAIGN_TEMPORARY_ID
                 ),
-              location => Google::Ads::GoogleAds::V9::Common::LocationInfo->new(
-                {
+              location =>
+                Google::Ads::GoogleAds::V10::Common::LocationInfo->new({
                   geoTargetConstant =>
-                    Google::Ads::GoogleAds::V9::Utils::ResourceNames::geo_target_constant(
+                    Google::Ads::GoogleAds::V10::Utils::ResourceNames::geo_target_constant(
                     1022762)}
-              ),
+                ),
               negative => "true"
             })})});
 
   # Set the LANGUAGE campaign criterion.
   push @$operations,
-    Google::Ads::GoogleAds::V9::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V10::Services::GoogleAdsService::MutateOperation->
     new({
       campaignCriterionOperation =>
-        Google::Ads::GoogleAds::V9::Services::CampaignCriterionService::CampaignCriterionOperation
+        Google::Ads::GoogleAds::V10::Services::CampaignCriterionService::CampaignCriterionOperation
         ->new({
           create =>
-            Google::Ads::GoogleAds::V9::Resources::CampaignCriterion->new({
+            Google::Ads::GoogleAds::V10::Resources::CampaignCriterion->new({
               campaign =>
-                Google::Ads::GoogleAds::V9::Utils::ResourceNames::campaign(
+                Google::Ads::GoogleAds::V10::Utils::ResourceNames::campaign(
                 $customer_id, PERFORMANCE_MAX_CAMPAIGN_TEMPORARY_ID
                 ),
               # Set the language.
               # For a list of all language codes, see:
               # https://developers.google.com/google-ads/api/reference/data/codes-formats#expandable-7.
-              language => Google::Ads::GoogleAds::V9::Common::LanguageInfo->new(
-                {
+              language =>
+                Google::Ads::GoogleAds::V10::Common::LanguageInfo->new({
                   languageConstant =>
-                    Google::Ads::GoogleAds::V9::Utils::ResourceNames::language_constant(
+                    Google::Ads::GoogleAds::V10::Utils::ResourceNames::language_constant(
                     1000)    # English
                 })})})});
 
@@ -348,14 +349,14 @@ sub create_multiple_text_assets {
   foreach my $text (@$texts) {
     # Create a mutate operation for a text asset.
     push @$operations,
-      Google::Ads::GoogleAds::V9::Services::GoogleAdsService::MutateOperation->
-      new({
+      Google::Ads::GoogleAds::V10::Services::GoogleAdsService::MutateOperation
+      ->new({
         assetOperation =>
-          Google::Ads::GoogleAds::V9::Services::AssetService::AssetOperation->
+          Google::Ads::GoogleAds::V10::Services::AssetService::AssetOperation->
           new({
-            create => Google::Ads::GoogleAds::V9::Resources::Asset->new({
-                textAsset => Google::Ads::GoogleAds::V9::Common::TextAsset->new(
-                  {
+            create => Google::Ads::GoogleAds::V10::Resources::Asset->new({
+                textAsset =>
+                  Google::Ads::GoogleAds::V10::Common::TextAsset->new({
                     text => $text
                   })})})});
   }
@@ -393,25 +394,25 @@ sub create_asset_group_operations {
   my $operations = [];
   # Create a mutate operation that creates an asset group operation.
   push @$operations,
-    Google::Ads::GoogleAds::V9::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V10::Services::GoogleAdsService::MutateOperation->
     new({
       assetGroupOperation =>
-        Google::Ads::GoogleAds::V9::Services::AssetGroupService::AssetGroupOperation
+        Google::Ads::GoogleAds::V10::Services::AssetGroupService::AssetGroupOperation
         ->new({
-          create => Google::Ads::GoogleAds::V9::Resources::AssetGroup->new({
+          create => Google::Ads::GoogleAds::V10::Resources::AssetGroup->new({
               resourceName =>
-                Google::Ads::GoogleAds::V9::Utils::ResourceNames::asset_group(
+                Google::Ads::GoogleAds::V10::Utils::ResourceNames::asset_group(
                 $customer_id, ASSET_GROUP_TEMPORARY_ID
                 ),
               name     => "Performance Max asset group #" . uniqid(),
               campaign =>
-                Google::Ads::GoogleAds::V9::Utils::ResourceNames::campaign(
+                Google::Ads::GoogleAds::V10::Utils::ResourceNames::campaign(
                 $customer_id, PERFORMANCE_MAX_CAMPAIGN_TEMPORARY_ID
                 ),
               finalUrls       => ["http://www.example.com"],
               finalMobileUrls => ["http://www.example.com"],
               status          =>
-                Google::Ads::GoogleAds::V9::Enums::AssetGroupStatusEnum::PAUSED
+                Google::Ads::GoogleAds::V10::Enums::AssetGroupStatusEnum::PAUSED
             })})});
 
   # For the list of required assets for a Performance Max campaign, see
@@ -431,16 +432,16 @@ sub create_asset_group_operations {
   # Link the headline assets.
   foreach my $resource_name (@$headline_asset_resource_names) {
     push @$operations,
-      Google::Ads::GoogleAds::V9::Services::GoogleAdsService::MutateOperation->
-      new({
+      Google::Ads::GoogleAds::V10::Services::GoogleAdsService::MutateOperation
+      ->new({
         assetGroupAssetOperation =>
-          Google::Ads::GoogleAds::V9::Services::AssetGroupAssetService::AssetGroupAssetOperation
+          Google::Ads::GoogleAds::V10::Services::AssetGroupAssetService::AssetGroupAssetOperation
           ->new({
             create =>
-              Google::Ads::GoogleAds::V9::Resources::AssetGroupAsset->new({
+              Google::Ads::GoogleAds::V10::Resources::AssetGroupAsset->new({
                 asset      => $resource_name,
                 assetGroup =>
-                  Google::Ads::GoogleAds::V9::Utils::ResourceNames::asset_group(
+                  Google::Ads::GoogleAds::V10::Utils::ResourceNames::asset_group(
                   $customer_id, ASSET_GROUP_TEMPORARY_ID
                   ),
                 fieldType => HEADLINE
@@ -450,16 +451,16 @@ sub create_asset_group_operations {
   # Link the description assets.
   foreach my $resource_name (@$description_asset_resource_names) {
     push @$operations,
-      Google::Ads::GoogleAds::V9::Services::GoogleAdsService::MutateOperation->
-      new({
+      Google::Ads::GoogleAds::V10::Services::GoogleAdsService::MutateOperation
+      ->new({
         assetGroupAssetOperation =>
-          Google::Ads::GoogleAds::V9::Services::AssetGroupAssetService::AssetGroupAssetOperation
+          Google::Ads::GoogleAds::V10::Services::AssetGroupAssetService::AssetGroupAssetOperation
           ->new({
             create =>
-              Google::Ads::GoogleAds::V9::Resources::AssetGroupAsset->new({
+              Google::Ads::GoogleAds::V10::Resources::AssetGroupAsset->new({
                 asset      => $resource_name,
                 assetGroup =>
-                  Google::Ads::GoogleAds::V9::Utils::ResourceNames::asset_group(
+                  Google::Ads::GoogleAds::V10::Utils::ResourceNames::asset_group(
                   $customer_id, ASSET_GROUP_TEMPORARY_ID
                   ),
                 fieldType => DESCRIPTION
@@ -483,19 +484,23 @@ sub create_asset_group_operations {
   push @$operations,
     @{
     create_and_link_image_asset($customer_id, "https://gaagl.page.link/bjYi",
-      LOGO)};
+      LOGO, "Marketing Logo")};
 
   # Create and link the marketing image asset.
   push @$operations,
     @{
-    create_and_link_image_asset($customer_id, "https://gaagl.page.link/Eit5",
-      MARKETING_IMAGE)};
+    create_and_link_image_asset(
+      $customer_id,    "https://gaagl.page.link/Eit5",
+      MARKETING_IMAGE, "Marketing Image"
+    )};
 
   # Create and link the square marketing image asset.
   push @$operations,
     @{
-    create_and_link_image_asset($customer_id, "https://gaagl.page.link/bjYi",
-      SQUARE_MARKETING_IMAGE)};
+    create_and_link_image_asset(
+      $customer_id,           "https://gaagl.page.link/bjYi",
+      SQUARE_MARKETING_IMAGE, "Square Marketing Image"
+    )};
 
   return $operations;
 }
@@ -509,34 +514,34 @@ sub create_and_link_text_asset {
   my $operations = [];
   # Create a new mutate operation for a text asset.
   push @$operations,
-    Google::Ads::GoogleAds::V9::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V10::Services::GoogleAdsService::MutateOperation->
     new({
       assetOperation =>
-        Google::Ads::GoogleAds::V9::Services::AssetService::AssetOperation->new(
-        {
-          create => Google::Ads::GoogleAds::V9::Resources::Asset->new({
+        Google::Ads::GoogleAds::V10::Services::AssetService::AssetOperation->
+        new({
+          create => Google::Ads::GoogleAds::V10::Resources::Asset->new({
               resourceName =>
-                Google::Ads::GoogleAds::V9::Utils::ResourceNames::asset(
+                Google::Ads::GoogleAds::V10::Utils::ResourceNames::asset(
                 $customer_id, $next_temp_id
                 ),
-              textAsset => Google::Ads::GoogleAds::V9::Common::TextAsset->new({
+              textAsset => Google::Ads::GoogleAds::V10::Common::TextAsset->new({
                   text => $text
                 })})})});
 
   # Create an asset group asset to link the asset to the asset group.
   push @$operations,
-    Google::Ads::GoogleAds::V9::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V10::Services::GoogleAdsService::MutateOperation->
     new({
       assetGroupAssetOperation =>
-        Google::Ads::GoogleAds::V9::Services::AssetGroupAssetService::AssetGroupAssetOperation
+        Google::Ads::GoogleAds::V10::Services::AssetGroupAssetService::AssetGroupAssetOperation
         ->new({
           create =>
-            Google::Ads::GoogleAds::V9::Resources::AssetGroupAsset->new({
-              asset => Google::Ads::GoogleAds::V9::Utils::ResourceNames::asset(
+            Google::Ads::GoogleAds::V10::Resources::AssetGroupAsset->new({
+              asset => Google::Ads::GoogleAds::V10::Utils::ResourceNames::asset(
                 $customer_id, $next_temp_id
               ),
               assetGroup =>
-                Google::Ads::GoogleAds::V9::Utils::ResourceNames::asset_group(
+                Google::Ads::GoogleAds::V10::Utils::ResourceNames::asset_group(
                 $customer_id, ASSET_GROUP_TEMPORARY_ID
                 ),
               fieldType => $field_type
@@ -550,39 +555,43 @@ sub create_and_link_text_asset {
 # Creates a list of MutateOperations that create a new linked image asset.
 # [START add_performance_max_campaign_8]
 sub create_and_link_image_asset {
-  my ($customer_id, $url, $field_type) = @_;
+  my ($customer_id, $url, $field_type, $asset_name) = @_;
 
   my $operations = [];
   # Create a new mutate operation for an image asset.
   push @$operations,
-    Google::Ads::GoogleAds::V9::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V10::Services::GoogleAdsService::MutateOperation->
     new({
       assetOperation =>
-        Google::Ads::GoogleAds::V9::Services::AssetService::AssetOperation->new(
-        {
-          create => Google::Ads::GoogleAds::V9::Resources::Asset->new({
+        Google::Ads::GoogleAds::V10::Services::AssetService::AssetOperation->
+        new({
+          create => Google::Ads::GoogleAds::V10::Resources::Asset->new({
               resourceName =>
-                Google::Ads::GoogleAds::V9::Utils::ResourceNames::asset(
+                Google::Ads::GoogleAds::V10::Utils::ResourceNames::asset(
                 $customer_id, $next_temp_id
                 ),
-              imageAsset => Google::Ads::GoogleAds::V9::Common::ImageAsset->new(
-                {
+              # Provide a unique friendly name to identify your asset.
+              # When there is an existing image asset with the same content but a different
+              # name, the new name will be dropped silently.
+              name       => $asset_name,
+              imageAsset =>
+                Google::Ads::GoogleAds::V10::Common::ImageAsset->new({
                   data => get_base64_data_from_url($url)})})})});
 
   # Create an asset group asset to link the asset to the asset group.
   push @$operations,
-    Google::Ads::GoogleAds::V9::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V10::Services::GoogleAdsService::MutateOperation->
     new({
       assetGroupAssetOperation =>
-        Google::Ads::GoogleAds::V9::Services::AssetGroupAssetService::AssetGroupAssetOperation
+        Google::Ads::GoogleAds::V10::Services::AssetGroupAssetService::AssetGroupAssetOperation
         ->new({
           create =>
-            Google::Ads::GoogleAds::V9::Resources::AssetGroupAsset->new({
-              asset => Google::Ads::GoogleAds::V9::Utils::ResourceNames::asset(
+            Google::Ads::GoogleAds::V10::Resources::AssetGroupAsset->new({
+              asset => Google::Ads::GoogleAds::V10::Utils::ResourceNames::asset(
                 $customer_id, $next_temp_id
               ),
               assetGroup =>
-                Google::Ads::GoogleAds::V9::Utils::ResourceNames::asset_group(
+                Google::Ads::GoogleAds::V10::Utils::ResourceNames::asset_group(
                 $customer_id, ASSET_GROUP_TEMPORARY_ID
                 ),
               fieldType => $field_type
