@@ -25,9 +25,10 @@ use lib "$Bin/../../lib";
 use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
 use Google::Ads::GoogleAds::Utils::SearchGoogleAdsIterator;
-use Google::Ads::GoogleAds::V9::Enums::PolicyApprovalStatusEnum qw(DISAPPROVED);
+use Google::Ads::GoogleAds::V10::Enums::PolicyApprovalStatusEnum
+  qw(DISAPPROVED);
 use
-  Google::Ads::GoogleAds::V9::Services::GoogleAdsService::SearchGoogleAdsRequest;
+  Google::Ads::GoogleAds::V10::Services::GoogleAdsService::SearchGoogleAdsRequest;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
@@ -59,7 +60,7 @@ sub get_all_disapproved_ads {
 
   # Create a search Google Ads request.
   my $search_request =
-    Google::Ads::GoogleAds::V9::Services::GoogleAdsService::SearchGoogleAdsRequest
+    Google::Ads::GoogleAds::V10::Services::GoogleAdsService::SearchGoogleAdsRequest
     ->new({
       customerId              => $customer_id,
       query                   => $search_query,
