@@ -34,22 +34,22 @@ use lib "$Bin/../../lib";
 use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
 use Google::Ads::GoogleAds::Utils::SearchStreamHandler;
-use Google::Ads::GoogleAds::V9::Resources::UserList;
-use Google::Ads::GoogleAds::V9::Resources::OfflineUserDataJob;
-use Google::Ads::GoogleAds::V9::Common::CrmBasedUserListInfo;
-use Google::Ads::GoogleAds::V9::Common::CustomerMatchUserListMetadata;
-use Google::Ads::GoogleAds::V9::Common::UserData;
-use Google::Ads::GoogleAds::V9::Common::UserIdentifier;
-use Google::Ads::GoogleAds::V9::Common::OfflineUserAddressInfo;
-use Google::Ads::GoogleAds::V9::Enums::CustomerMatchUploadKeyTypeEnum
+use Google::Ads::GoogleAds::V10::Resources::UserList;
+use Google::Ads::GoogleAds::V10::Resources::OfflineUserDataJob;
+use Google::Ads::GoogleAds::V10::Common::CrmBasedUserListInfo;
+use Google::Ads::GoogleAds::V10::Common::CustomerMatchUserListMetadata;
+use Google::Ads::GoogleAds::V10::Common::UserData;
+use Google::Ads::GoogleAds::V10::Common::UserIdentifier;
+use Google::Ads::GoogleAds::V10::Common::OfflineUserAddressInfo;
+use Google::Ads::GoogleAds::V10::Enums::CustomerMatchUploadKeyTypeEnum
   qw(CONTACT_INFO);
-use Google::Ads::GoogleAds::V9::Enums::OfflineUserDataJobTypeEnum
+use Google::Ads::GoogleAds::V10::Enums::OfflineUserDataJobTypeEnum
   qw(CUSTOMER_MATCH_USER_LIST);
-use Google::Ads::GoogleAds::V9::Services::UserListService::UserListOperation;
+use Google::Ads::GoogleAds::V10::Services::UserListService::UserListOperation;
 use
-  Google::Ads::GoogleAds::V9::Services::OfflineUserDataJobService::OfflineUserDataJobOperation;
+  Google::Ads::GoogleAds::V10::Services::OfflineUserDataJobService::OfflineUserDataJobOperation;
 use
-  Google::Ads::GoogleAds::V9::Services::GoogleAdsService::SearchGoogleAdsStreamRequest;
+  Google::Ads::GoogleAds::V10::Services::GoogleAdsService::SearchGoogleAdsStreamRequest;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
@@ -88,7 +88,7 @@ sub create_customer_match_user_list {
   my ($api_client, $customer_id) = @_;
 
   # Create the user list.
-  my $user_list = Google::Ads::GoogleAds::V9::Resources::UserList->new({
+  my $user_list = Google::Ads::GoogleAds::V10::Resources::UserList->new({
       name        => "Customer Match list #" . uniqid(),
       description =>
         "A list of customers that originated from email and physical addresses",
@@ -97,13 +97,13 @@ sub create_customer_match_user_list {
       # Set the membership life span to 30 days.
       membershipLifeSpan => 30,
       crmBasedUserList   =>
-        Google::Ads::GoogleAds::V9::Common::CrmBasedUserListInfo->new({
+        Google::Ads::GoogleAds::V10::Common::CrmBasedUserListInfo->new({
           uploadKeyType => CONTACT_INFO
         })});
 
   # Create the user list operation.
   my $user_list_operation =
-    Google::Ads::GoogleAds::V9::Services::UserListService::UserListOperation->
+    Google::Ads::GoogleAds::V10::Services::UserListService::UserListOperation->
     new({
       create => $user_list
     });
@@ -130,10 +130,11 @@ sub add_users_to_customer_match_user_list {
 
   # Create a new offline user data job.
   my $offline_user_data_job =
-    Google::Ads::GoogleAds::V9::Resources::OfflineUserDataJob->new({
+    Google::Ads::GoogleAds::V10::Resources::OfflineUserDataJob->new({
       type                          => CUSTOMER_MATCH_USER_LIST,
       customerMatchUserListMetadata =>
-        Google::Ads::GoogleAds::V9::Common::CustomerMatchUserListMetadata->new({
+        Google::Ads::GoogleAds::V10::Common::CustomerMatchUserListMetadata->new(
+        {
           userList => $user_list_resource_name
         })});
 
@@ -209,19 +210,19 @@ sub build_offline_user_data_job_operations() {
   # [START add_customer_match_user_list_2]
   # Create a first user data based on an email address.
   my $user_data_with_email_address =
-    Google::Ads::GoogleAds::V9::Common::UserData->new({
+    Google::Ads::GoogleAds::V10::Common::UserData->new({
       userIdentifiers => [
-        Google::Ads::GoogleAds::V9::Common::UserIdentifier->new({
+        Google::Ads::GoogleAds::V10::Common::UserIdentifier->new({
             # Hash normalized email addresses based on SHA-256 hashing algorithm.
             hashedEmail => normalize_and_hash('customer@example.com')})]});
 
   # Create a second user data based on a physical address.
   my $user_data_with_physical_address =
-    Google::Ads::GoogleAds::V9::Common::UserData->new({
+    Google::Ads::GoogleAds::V10::Common::UserData->new({
       userIdentifiers => [
-        Google::Ads::GoogleAds::V9::Common::UserIdentifier->new({
+        Google::Ads::GoogleAds::V10::Common::UserIdentifier->new({
             addressInfo =>
-              Google::Ads::GoogleAds::V9::Common::OfflineUserAddressInfo->new({
+              Google::Ads::GoogleAds::V10::Common::OfflineUserAddressInfo->new({
                 # First and last name must be normalized and hashed.
                 hashedFirstName => normalize_and_hash("John"),
                 hashedLastName  => normalize_and_hash("Doe"),
@@ -233,12 +234,12 @@ sub build_offline_user_data_job_operations() {
 
   # Create the operations to add the two users.
   my $operations = [
-    Google::Ads::GoogleAds::V9::Services::OfflineUserDataJobService::OfflineUserDataJobOperation
+    Google::Ads::GoogleAds::V10::Services::OfflineUserDataJobService::OfflineUserDataJobOperation
       ->new({
         create => $user_data_with_email_address
       }
       ),
-    Google::Ads::GoogleAds::V9::Services::OfflineUserDataJobService::OfflineUserDataJobOperation
+    Google::Ads::GoogleAds::V10::Services::OfflineUserDataJobService::OfflineUserDataJobOperation
       ->new({
         create => $user_data_with_physical_address
       })];
@@ -258,7 +259,7 @@ sub print_customer_match_user_list_info {
 
   # Create a search Google Ads stream request that will retrieve the user list.
   my $search_stream_request =
-    Google::Ads::GoogleAds::V9::Services::GoogleAdsService::SearchGoogleAdsStreamRequest
+    Google::Ads::GoogleAds::V10::Services::GoogleAdsService::SearchGoogleAdsStreamRequest
     ->new({
       customerId => $customer_id,
       query      => $search_query,
