@@ -45,43 +45,43 @@ use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
 use Google::Ads::GoogleAds::Utils::MediaUtils;
 use Google::Ads::GoogleAds::Utils::FieldMasks;
-use Google::Ads::GoogleAds::V9::Resources::CampaignBudget;
-use Google::Ads::GoogleAds::V9::Resources::Campaign;
-use Google::Ads::GoogleAds::V9::Resources::ShoppingSetting;
-use Google::Ads::GoogleAds::V9::Resources::CampaignCriterion;
-use Google::Ads::GoogleAds::V9::Resources::Asset;
-use Google::Ads::GoogleAds::V9::Resources::AssetGroup;
-use Google::Ads::GoogleAds::V9::Resources::AssetGroupAsset;
-use Google::Ads::GoogleAds::V9::Resources::CampaignConversionGoal;
-use Google::Ads::GoogleAds::V9::Common::MaximizeConversionValue;
-use Google::Ads::GoogleAds::V9::Common::LocationInfo;
-use Google::Ads::GoogleAds::V9::Common::LanguageInfo;
-use Google::Ads::GoogleAds::V9::Common::TextAsset;
-use Google::Ads::GoogleAds::V9::Common::ImageAsset;
-use Google::Ads::GoogleAds::V9::Enums::BudgetDeliveryMethodEnum qw(STANDARD);
-use Google::Ads::GoogleAds::V9::Enums::CampaignStatusEnum;
-use Google::Ads::GoogleAds::V9::Enums::AdvertisingChannelTypeEnum
+use Google::Ads::GoogleAds::V10::Resources::CampaignBudget;
+use Google::Ads::GoogleAds::V10::Resources::Campaign;
+use Google::Ads::GoogleAds::V10::Resources::ShoppingSetting;
+use Google::Ads::GoogleAds::V10::Resources::CampaignCriterion;
+use Google::Ads::GoogleAds::V10::Resources::Asset;
+use Google::Ads::GoogleAds::V10::Resources::AssetGroup;
+use Google::Ads::GoogleAds::V10::Resources::AssetGroupAsset;
+use Google::Ads::GoogleAds::V10::Resources::CampaignConversionGoal;
+use Google::Ads::GoogleAds::V10::Common::MaximizeConversionValue;
+use Google::Ads::GoogleAds::V10::Common::LocationInfo;
+use Google::Ads::GoogleAds::V10::Common::LanguageInfo;
+use Google::Ads::GoogleAds::V10::Common::TextAsset;
+use Google::Ads::GoogleAds::V10::Common::ImageAsset;
+use Google::Ads::GoogleAds::V10::Enums::BudgetDeliveryMethodEnum qw(STANDARD);
+use Google::Ads::GoogleAds::V10::Enums::CampaignStatusEnum;
+use Google::Ads::GoogleAds::V10::Enums::AdvertisingChannelTypeEnum
   qw(PERFORMANCE_MAX);
-use Google::Ads::GoogleAds::V9::Enums::AssetGroupStatusEnum;
-use Google::Ads::GoogleAds::V9::Enums::AssetFieldTypeEnum
+use Google::Ads::GoogleAds::V10::Enums::AssetGroupStatusEnum;
+use Google::Ads::GoogleAds::V10::Enums::AssetFieldTypeEnum
   qw(HEADLINE DESCRIPTION LONG_HEADLINE BUSINESS_NAME LOGO MARKETING_IMAGE SQUARE_MARKETING_IMAGE);
-use Google::Ads::GoogleAds::V9::Enums::ConversionActionCategoryEnum
+use Google::Ads::GoogleAds::V10::Enums::ConversionActionCategoryEnum
   qw(PURCHASE);
-use Google::Ads::GoogleAds::V9::Enums::ConversionOriginEnum qw(WEBSITE);
-use Google::Ads::GoogleAds::V9::Services::GoogleAdsService::MutateOperation;
+use Google::Ads::GoogleAds::V10::Enums::ConversionOriginEnum qw(WEBSITE);
+use Google::Ads::GoogleAds::V10::Services::GoogleAdsService::MutateOperation;
 use
-  Google::Ads::GoogleAds::V9::Services::CampaignBudgetService::CampaignBudgetOperation;
-use Google::Ads::GoogleAds::V9::Services::CampaignService::CampaignOperation;
+  Google::Ads::GoogleAds::V10::Services::CampaignBudgetService::CampaignBudgetOperation;
+use Google::Ads::GoogleAds::V10::Services::CampaignService::CampaignOperation;
 use
-  Google::Ads::GoogleAds::V9::Services::CampaignCriterionService::CampaignCriterionOperation;
-use Google::Ads::GoogleAds::V9::Services::AssetService::AssetOperation;
+  Google::Ads::GoogleAds::V10::Services::CampaignCriterionService::CampaignCriterionOperation;
+use Google::Ads::GoogleAds::V10::Services::AssetService::AssetOperation;
 use
-  Google::Ads::GoogleAds::V9::Services::AssetGroupService::AssetGroupOperation;
+  Google::Ads::GoogleAds::V10::Services::AssetGroupService::AssetGroupOperation;
 use
-  Google::Ads::GoogleAds::V9::Services::AssetGroupAssetService::AssetGroupAssetOperation;
+  Google::Ads::GoogleAds::V10::Services::AssetGroupAssetService::AssetGroupAssetOperation;
 use
-  Google::Ads::GoogleAds::V9::Services::CampaignConversionGoalService::CampaignConversionGoalOperation;
-use Google::Ads::GoogleAds::V9::Utils::ResourceNames;
+  Google::Ads::GoogleAds::V10::Services::CampaignConversionGoalService::CampaignConversionGoalOperation;
+use Google::Ads::GoogleAds::V10::Utils::ResourceNames;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
@@ -192,16 +192,17 @@ sub create_campaign_budget_operation {
 
   # Create a mutate operation that creates a campaign budget operation.
   return
-    Google::Ads::GoogleAds::V9::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V10::Services::GoogleAdsService::MutateOperation->
     new({
       campaignBudgetOperation =>
-        Google::Ads::GoogleAds::V9::Services::CampaignBudgetService::CampaignBudgetOperation
+        Google::Ads::GoogleAds::V10::Services::CampaignBudgetService::CampaignBudgetOperation
         ->new({
-          create => Google::Ads::GoogleAds::V9::Resources::CampaignBudget->new({
+          create => Google::Ads::GoogleAds::V10::Resources::CampaignBudget->new(
+            {
               # Set a temporary ID in the budget's resource name so it can be
               # referenced by the campaign in later steps.
               resourceName =>
-                Google::Ads::GoogleAds::V9::Utils::ResourceNames::campaign_budget(
+                Google::Ads::GoogleAds::V10::Utils::ResourceNames::campaign_budget(
                 $customer_id, BUDGET_TEMPORARY_ID
                 ),
               name => "Performance Max retail campaign budget #" . uniqid(),
@@ -224,27 +225,27 @@ sub create_performance_max_campaign_operation {
 
   # Create a mutate operation that creates a campaign operation.
   return
-    Google::Ads::GoogleAds::V9::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V10::Services::GoogleAdsService::MutateOperation->
     new({
       campaignOperation =>
-        Google::Ads::GoogleAds::V9::Services::CampaignService::CampaignOperation
+        Google::Ads::GoogleAds::V10::Services::CampaignService::CampaignOperation
         ->new({
-          create => Google::Ads::GoogleAds::V9::Resources::Campaign->new({
+          create => Google::Ads::GoogleAds::V10::Resources::Campaign->new({
               # Assign the resource name with a temporary ID.
               resourceName =>
-                Google::Ads::GoogleAds::V9::Utils::ResourceNames::campaign(
+                Google::Ads::GoogleAds::V10::Utils::ResourceNames::campaign(
                 $customer_id, PERFORMANCE_MAX_CAMPAIGN_TEMPORARY_ID
                 ),
               name => "Performance Max retail campaign #'" . uniqid(),
               # Set the budget using the given budget resource name.
               campaignBudget =>
-                Google::Ads::GoogleAds::V9::Utils::ResourceNames::campaign_budget(
+                Google::Ads::GoogleAds::V10::Utils::ResourceNames::campaign_budget(
                 $customer_id, BUDGET_TEMPORARY_ID
                 ),
               # Set the campaign status as PAUSED. The campaign is the only entity in
               # the mutate request that should have its status set.
               status =>
-                Google::Ads::GoogleAds::V9::Enums::CampaignStatusEnum::PAUSED,
+                Google::Ads::GoogleAds::V10::Enums::CampaignStatusEnum::PAUSED,
               # All Performance Max campaigns have an advertisingChannelType of
               # PERFORMANCE_MAX. The advertisingChannelSubType should not be set.
               advertisingChannelType => PERFORMANCE_MAX,
@@ -260,7 +261,7 @@ sub create_performance_max_campaign_operation {
               # http://support.google.com/google-ads/answer/7684216.
               # A targetRoas of 3.5 corresponds to a 350% return on ad spend.
               maximizeConversionValue =>
-                Google::Ads::GoogleAds::V9::Common::MaximizeConversionValue->
+                Google::Ads::GoogleAds::V10::Common::MaximizeConversionValue->
                 new({
                   targetRoas => 3.5
                 }
@@ -277,7 +278,7 @@ sub create_performance_max_campaign_operation {
 
               # Set the shopping settings.
               shoppingSetting =>
-                Google::Ads::GoogleAds::V9::Resources::ShoppingSetting->new({
+                Google::Ads::GoogleAds::V10::Resources::ShoppingSetting->new({
                   merchantId   => $merchant_center_account_id,
                   salesCountry => $sales_country
                 }
@@ -308,68 +309,68 @@ sub create_campaign_criterion_operations {
   # and one negative location target for Brooklyn (ID=1022762).
   # First, add the positive (negative = false) for New York City.
   push @$operations,
-    Google::Ads::GoogleAds::V9::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V10::Services::GoogleAdsService::MutateOperation->
     new({
       campaignCriterionOperation =>
-        Google::Ads::GoogleAds::V9::Services::CampaignCriterionService::CampaignCriterionOperation
+        Google::Ads::GoogleAds::V10::Services::CampaignCriterionService::CampaignCriterionOperation
         ->new({
           create =>
-            Google::Ads::GoogleAds::V9::Resources::CampaignCriterion->new({
+            Google::Ads::GoogleAds::V10::Resources::CampaignCriterion->new({
               campaign =>
-                Google::Ads::GoogleAds::V9::Utils::ResourceNames::campaign(
+                Google::Ads::GoogleAds::V10::Utils::ResourceNames::campaign(
                 $customer_id, PERFORMANCE_MAX_CAMPAIGN_TEMPORARY_ID
                 ),
-              location => Google::Ads::GoogleAds::V9::Common::LocationInfo->new(
-                {
+              location =>
+                Google::Ads::GoogleAds::V10::Common::LocationInfo->new({
                   geoTargetConstant =>
-                    Google::Ads::GoogleAds::V9::Utils::ResourceNames::geo_target_constant(
+                    Google::Ads::GoogleAds::V10::Utils::ResourceNames::geo_target_constant(
                     1023191)}
-              ),
+                ),
               negative => "false"
             })})});
 
   # Next add the negative target for Brooklyn.
   push @$operations,
-    Google::Ads::GoogleAds::V9::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V10::Services::GoogleAdsService::MutateOperation->
     new({
       campaignCriterionOperation =>
-        Google::Ads::GoogleAds::V9::Services::CampaignCriterionService::CampaignCriterionOperation
+        Google::Ads::GoogleAds::V10::Services::CampaignCriterionService::CampaignCriterionOperation
         ->new({
           create =>
-            Google::Ads::GoogleAds::V9::Resources::CampaignCriterion->new({
+            Google::Ads::GoogleAds::V10::Resources::CampaignCriterion->new({
               campaign =>
-                Google::Ads::GoogleAds::V9::Utils::ResourceNames::campaign(
+                Google::Ads::GoogleAds::V10::Utils::ResourceNames::campaign(
                 $customer_id, PERFORMANCE_MAX_CAMPAIGN_TEMPORARY_ID
                 ),
-              location => Google::Ads::GoogleAds::V9::Common::LocationInfo->new(
-                {
+              location =>
+                Google::Ads::GoogleAds::V10::Common::LocationInfo->new({
                   geoTargetConstant =>
-                    Google::Ads::GoogleAds::V9::Utils::ResourceNames::geo_target_constant(
+                    Google::Ads::GoogleAds::V10::Utils::ResourceNames::geo_target_constant(
                     1022762)}
-              ),
+                ),
               negative => "true"
             })})});
 
   # Set the LANGUAGE campaign criterion.
   push @$operations,
-    Google::Ads::GoogleAds::V9::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V10::Services::GoogleAdsService::MutateOperation->
     new({
       campaignCriterionOperation =>
-        Google::Ads::GoogleAds::V9::Services::CampaignCriterionService::CampaignCriterionOperation
+        Google::Ads::GoogleAds::V10::Services::CampaignCriterionService::CampaignCriterionOperation
         ->new({
           create =>
-            Google::Ads::GoogleAds::V9::Resources::CampaignCriterion->new({
+            Google::Ads::GoogleAds::V10::Resources::CampaignCriterion->new({
               campaign =>
-                Google::Ads::GoogleAds::V9::Utils::ResourceNames::campaign(
+                Google::Ads::GoogleAds::V10::Utils::ResourceNames::campaign(
                 $customer_id, PERFORMANCE_MAX_CAMPAIGN_TEMPORARY_ID
                 ),
               # Set the language.
               # For a list of all language codes, see:
               # https://developers.google.com/google-ads/api/reference/data/codes-formats#expandable-7.
-              language => Google::Ads::GoogleAds::V9::Common::LanguageInfo->new(
-                {
+              language =>
+                Google::Ads::GoogleAds::V10::Common::LanguageInfo->new({
                   languageConstant =>
-                    Google::Ads::GoogleAds::V9::Utils::ResourceNames::language_constant(
+                    Google::Ads::GoogleAds::V10::Utils::ResourceNames::language_constant(
                     1000)    # English
                 })})})});
 
@@ -388,14 +389,14 @@ sub create_multiple_text_assets {
   foreach my $text (@$texts) {
     # Create a mutate operation for a text asset.
     push @$operations,
-      Google::Ads::GoogleAds::V9::Services::GoogleAdsService::MutateOperation->
-      new({
+      Google::Ads::GoogleAds::V10::Services::GoogleAdsService::MutateOperation
+      ->new({
         assetOperation =>
-          Google::Ads::GoogleAds::V9::Services::AssetService::AssetOperation->
+          Google::Ads::GoogleAds::V10::Services::AssetService::AssetOperation->
           new({
-            create => Google::Ads::GoogleAds::V9::Resources::Asset->new({
-                textAsset => Google::Ads::GoogleAds::V9::Common::TextAsset->new(
-                  {
+            create => Google::Ads::GoogleAds::V10::Resources::Asset->new({
+                textAsset =>
+                  Google::Ads::GoogleAds::V10::Common::TextAsset->new({
                     text => $text
                   })})})});
   }
@@ -433,25 +434,25 @@ sub create_asset_group_operations {
   my $operations = [];
   # Create a mutate operation that creates an asset group operation.
   push @$operations,
-    Google::Ads::GoogleAds::V9::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V10::Services::GoogleAdsService::MutateOperation->
     new({
       assetGroupOperation =>
-        Google::Ads::GoogleAds::V9::Services::AssetGroupService::AssetGroupOperation
+        Google::Ads::GoogleAds::V10::Services::AssetGroupService::AssetGroupOperation
         ->new({
-          create => Google::Ads::GoogleAds::V9::Resources::AssetGroup->new({
+          create => Google::Ads::GoogleAds::V10::Resources::AssetGroup->new({
               resourceName =>
-                Google::Ads::GoogleAds::V9::Utils::ResourceNames::asset_group(
+                Google::Ads::GoogleAds::V10::Utils::ResourceNames::asset_group(
                 $customer_id, ASSET_GROUP_TEMPORARY_ID
                 ),
               name     => "Performance Max retail asset group #" . uniqid(),
               campaign =>
-                Google::Ads::GoogleAds::V9::Utils::ResourceNames::campaign(
+                Google::Ads::GoogleAds::V10::Utils::ResourceNames::campaign(
                 $customer_id, PERFORMANCE_MAX_CAMPAIGN_TEMPORARY_ID
                 ),
               finalUrls       => [$final_url],
               finalMobileUrls => [$final_url],
               status          =>
-                Google::Ads::GoogleAds::V9::Enums::AssetGroupStatusEnum::PAUSED
+                Google::Ads::GoogleAds::V10::Enums::AssetGroupStatusEnum::PAUSED
             })})});
 
   # For the list of required assets for a Performance Max campaign, see
@@ -471,16 +472,16 @@ sub create_asset_group_operations {
   # Link the headline assets.
   foreach my $resource_name (@$headline_asset_resource_names) {
     push @$operations,
-      Google::Ads::GoogleAds::V9::Services::GoogleAdsService::MutateOperation->
-      new({
+      Google::Ads::GoogleAds::V10::Services::GoogleAdsService::MutateOperation
+      ->new({
         assetGroupAssetOperation =>
-          Google::Ads::GoogleAds::V9::Services::AssetGroupAssetService::AssetGroupAssetOperation
+          Google::Ads::GoogleAds::V10::Services::AssetGroupAssetService::AssetGroupAssetOperation
           ->new({
             create =>
-              Google::Ads::GoogleAds::V9::Resources::AssetGroupAsset->new({
+              Google::Ads::GoogleAds::V10::Resources::AssetGroupAsset->new({
                 asset      => $resource_name,
                 assetGroup =>
-                  Google::Ads::GoogleAds::V9::Utils::ResourceNames::asset_group(
+                  Google::Ads::GoogleAds::V10::Utils::ResourceNames::asset_group(
                   $customer_id, ASSET_GROUP_TEMPORARY_ID
                   ),
                 fieldType => HEADLINE
@@ -490,16 +491,16 @@ sub create_asset_group_operations {
   # Link the description assets.
   foreach my $resource_name (@$description_asset_resource_names) {
     push @$operations,
-      Google::Ads::GoogleAds::V9::Services::GoogleAdsService::MutateOperation->
-      new({
+      Google::Ads::GoogleAds::V10::Services::GoogleAdsService::MutateOperation
+      ->new({
         assetGroupAssetOperation =>
-          Google::Ads::GoogleAds::V9::Services::AssetGroupAssetService::AssetGroupAssetOperation
+          Google::Ads::GoogleAds::V10::Services::AssetGroupAssetService::AssetGroupAssetOperation
           ->new({
             create =>
-              Google::Ads::GoogleAds::V9::Resources::AssetGroupAsset->new({
+              Google::Ads::GoogleAds::V10::Resources::AssetGroupAsset->new({
                 asset      => $resource_name,
                 assetGroup =>
-                  Google::Ads::GoogleAds::V9::Utils::ResourceNames::asset_group(
+                  Google::Ads::GoogleAds::V10::Utils::ResourceNames::asset_group(
                   $customer_id, ASSET_GROUP_TEMPORARY_ID
                   ),
                 fieldType => DESCRIPTION
@@ -523,19 +524,23 @@ sub create_asset_group_operations {
   push @$operations,
     @{
     create_and_link_image_asset($customer_id, "https://gaagl.page.link/bjYi",
-      LOGO)};
+      LOGO, "Logo Image")};
 
   # Create and link the marketing image asset.
   push @$operations,
     @{
-    create_and_link_image_asset($customer_id, "https://gaagl.page.link/Eit5",
-      MARKETING_IMAGE)};
+    create_and_link_image_asset(
+      $customer_id,    "https://gaagl.page.link/Eit5",
+      MARKETING_IMAGE, "Marketing Image"
+    )};
 
   # Create and link the square marketing image asset.
   push @$operations,
     @{
-    create_and_link_image_asset($customer_id, "https://gaagl.page.link/bjYi",
-      SQUARE_MARKETING_IMAGE)};
+    create_and_link_image_asset(
+      $customer_id,           "https://gaagl.page.link/bjYi",
+      SQUARE_MARKETING_IMAGE, "Square Marketing Image"
+    )};
 
   return $operations;
 }
@@ -549,34 +554,34 @@ sub create_and_link_text_asset {
   my $operations = [];
   # Create a new mutate operation for a text asset.
   push @$operations,
-    Google::Ads::GoogleAds::V9::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V10::Services::GoogleAdsService::MutateOperation->
     new({
       assetOperation =>
-        Google::Ads::GoogleAds::V9::Services::AssetService::AssetOperation->new(
-        {
-          create => Google::Ads::GoogleAds::V9::Resources::Asset->new({
+        Google::Ads::GoogleAds::V10::Services::AssetService::AssetOperation->
+        new({
+          create => Google::Ads::GoogleAds::V10::Resources::Asset->new({
               resourceName =>
-                Google::Ads::GoogleAds::V9::Utils::ResourceNames::asset(
+                Google::Ads::GoogleAds::V10::Utils::ResourceNames::asset(
                 $customer_id, $next_temp_id
                 ),
-              textAsset => Google::Ads::GoogleAds::V9::Common::TextAsset->new({
+              textAsset => Google::Ads::GoogleAds::V10::Common::TextAsset->new({
                   text => $text
                 })})})});
 
   # Create an asset group asset to link the asset to the asset group.
   push @$operations,
-    Google::Ads::GoogleAds::V9::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V10::Services::GoogleAdsService::MutateOperation->
     new({
       assetGroupAssetOperation =>
-        Google::Ads::GoogleAds::V9::Services::AssetGroupAssetService::AssetGroupAssetOperation
+        Google::Ads::GoogleAds::V10::Services::AssetGroupAssetService::AssetGroupAssetOperation
         ->new({
           create =>
-            Google::Ads::GoogleAds::V9::Resources::AssetGroupAsset->new({
-              asset => Google::Ads::GoogleAds::V9::Utils::ResourceNames::asset(
+            Google::Ads::GoogleAds::V10::Resources::AssetGroupAsset->new({
+              asset => Google::Ads::GoogleAds::V10::Utils::ResourceNames::asset(
                 $customer_id, $next_temp_id
               ),
               assetGroup =>
-                Google::Ads::GoogleAds::V9::Utils::ResourceNames::asset_group(
+                Google::Ads::GoogleAds::V10::Utils::ResourceNames::asset_group(
                 $customer_id, ASSET_GROUP_TEMPORARY_ID
                 ),
               fieldType => $field_type
@@ -590,39 +595,43 @@ sub create_and_link_text_asset {
 # Creates a list of MutateOperations that create a new linked image asset.
 # [START add_performance_max_retail_campaign_8]
 sub create_and_link_image_asset {
-  my ($customer_id, $url, $field_type) = @_;
+  my ($customer_id, $url, $field_type, $asset_name) = @_;
 
   my $operations = [];
   # Create a new mutate operation for an image asset.
   push @$operations,
-    Google::Ads::GoogleAds::V9::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V10::Services::GoogleAdsService::MutateOperation->
     new({
       assetOperation =>
-        Google::Ads::GoogleAds::V9::Services::AssetService::AssetOperation->new(
-        {
-          create => Google::Ads::GoogleAds::V9::Resources::Asset->new({
+        Google::Ads::GoogleAds::V10::Services::AssetService::AssetOperation->
+        new({
+          create => Google::Ads::GoogleAds::V10::Resources::Asset->new({
               resourceName =>
-                Google::Ads::GoogleAds::V9::Utils::ResourceNames::asset(
+                Google::Ads::GoogleAds::V10::Utils::ResourceNames::asset(
                 $customer_id, $next_temp_id
                 ),
-              imageAsset => Google::Ads::GoogleAds::V9::Common::ImageAsset->new(
-                {
+              # Provide a unique friendly name to identify your asset.
+              # When there is an existing image asset with the same content but a different
+              # name, the new name will be dropped silently.
+              name       => $asset_name,
+              imageAsset =>
+                Google::Ads::GoogleAds::V10::Common::ImageAsset->new({
                   data => get_base64_data_from_url($url)})})})});
 
   # Create an asset group asset to link the asset to the asset group.
   push @$operations,
-    Google::Ads::GoogleAds::V9::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V10::Services::GoogleAdsService::MutateOperation->
     new({
       assetGroupAssetOperation =>
-        Google::Ads::GoogleAds::V9::Services::AssetGroupAssetService::AssetGroupAssetOperation
+        Google::Ads::GoogleAds::V10::Services::AssetGroupAssetService::AssetGroupAssetOperation
         ->new({
           create =>
-            Google::Ads::GoogleAds::V9::Resources::AssetGroupAsset->new({
-              asset => Google::Ads::GoogleAds::V9::Utils::ResourceNames::asset(
+            Google::Ads::GoogleAds::V10::Resources::AssetGroupAsset->new({
+              asset => Google::Ads::GoogleAds::V10::Utils::ResourceNames::asset(
                 $customer_id, $next_temp_id
               ),
               assetGroup =>
-                Google::Ads::GoogleAds::V9::Utils::ResourceNames::asset_group(
+                Google::Ads::GoogleAds::V10::Utils::ResourceNames::asset_group(
                 $customer_id, ASSET_GROUP_TEMPORARY_ID
                 ),
               fieldType => $field_type
@@ -672,9 +681,9 @@ sub create_conversion_goal_operations {
   # is biddable in this campaign.
   foreach my $customer_conversion_goal (@$customer_conversion_goals) {
     my $campaign_conversion_goal =
-      Google::Ads::GoogleAds::V9::Resources::CampaignConversionGoal->new({
+      Google::Ads::GoogleAds::V10::Resources::CampaignConversionGoal->new({
         resourceName =>
-          Google::Ads::GoogleAds::V9::Utils::ResourceNames::campaign_conversion_goal(
+          Google::Ads::GoogleAds::V10::Utils::ResourceNames::campaign_conversion_goal(
           $customer_id,
           PERFORMANCE_MAX_CAMPAIGN_TEMPORARY_ID,
           $customer_conversion_goal->{category},
@@ -696,10 +705,10 @@ sub create_conversion_goal_operations {
     }
 
     push @$operations,
-      Google::Ads::GoogleAds::V9::Services::GoogleAdsService::MutateOperation->
-      new({
+      Google::Ads::GoogleAds::V10::Services::GoogleAdsService::MutateOperation
+      ->new({
         campaignConversionGoalOperation =>
-          Google::Ads::GoogleAds::V9::Services::CampaignConversionGoalService::CampaignConversionGoalOperation
+          Google::Ads::GoogleAds::V10::Services::CampaignConversionGoalService::CampaignConversionGoalOperation
           ->new({
             update => $campaign_conversion_goal,
             # Set the update mask on the operation. Here the update mask will be
