@@ -34,20 +34,20 @@ use lib "$Bin/../../lib";
 use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
 use Google::Ads::GoogleAds::Utils::SearchGoogleAdsIterator;
-use Google::Ads::GoogleAds::V9::Resources::AdGroupCriterion;
-use Google::Ads::GoogleAds::V9::Common::ListingGroupInfo;
-use Google::Ads::GoogleAds::V9::Common::ListingDimensionInfo;
-use Google::Ads::GoogleAds::V9::Common::ProductConditionInfo;
-use Google::Ads::GoogleAds::V9::Common::ProductBrandInfo;
-use Google::Ads::GoogleAds::V9::Enums::ListingGroupTypeEnum
+use Google::Ads::GoogleAds::V10::Resources::AdGroupCriterion;
+use Google::Ads::GoogleAds::V10::Common::ListingGroupInfo;
+use Google::Ads::GoogleAds::V10::Common::ListingDimensionInfo;
+use Google::Ads::GoogleAds::V10::Common::ProductConditionInfo;
+use Google::Ads::GoogleAds::V10::Common::ProductBrandInfo;
+use Google::Ads::GoogleAds::V10::Enums::ListingGroupTypeEnum
   qw(SUBDIVISION UNIT);
-use Google::Ads::GoogleAds::V9::Enums::AdGroupCriterionStatusEnum qw(ENABLED);
-use Google::Ads::GoogleAds::V9::Enums::ProductConditionEnum qw(NEW USED);
+use Google::Ads::GoogleAds::V10::Enums::AdGroupCriterionStatusEnum qw(ENABLED);
+use Google::Ads::GoogleAds::V10::Enums::ProductConditionEnum qw(NEW USED);
 use
-  Google::Ads::GoogleAds::V9::Services::AdGroupCriterionService::AdGroupCriterionOperation;
+  Google::Ads::GoogleAds::V10::Services::AdGroupCriterionService::AdGroupCriterionOperation;
 use
-  Google::Ads::GoogleAds::V9::Services::GoogleAdsService::SearchGoogleAdsRequest;
-use Google::Ads::GoogleAds::V9::Utils::ResourceNames;
+  Google::Ads::GoogleAds::V10::Services::GoogleAdsService::SearchGoogleAdsRequest;
+use Google::Ads::GoogleAds::V10::Utils::ResourceNames;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
@@ -92,7 +92,7 @@ sub add_shopping_product_listing_group_tree {
   my $ad_group_criterion_root_resource_name =
     $ad_group_criterion_root->{resourceName};
   push @$operations,
-    Google::Ads::GoogleAds::V9::Services::AdGroupCriterionService::AdGroupCriterionOperation
+    Google::Ads::GoogleAds::V10::Services::AdGroupCriterionService::AdGroupCriterionOperation
     ->new({
       create => $ad_group_criterion_root
     });
@@ -106,16 +106,16 @@ sub add_shopping_product_listing_group_tree {
     $customer_id,
     $ad_group_id,
     $ad_group_criterion_root_resource_name,
-    Google::Ads::GoogleAds::V9::Common::ListingDimensionInfo->new({
+    Google::Ads::GoogleAds::V10::Common::ListingDimensionInfo->new({
         productCondition =>
-          Google::Ads::GoogleAds::V9::Common::ProductConditionInfo->new({
+          Google::Ads::GoogleAds::V10::Common::ProductConditionInfo->new({
             condition => NEW
           })}
     ),
     200000
   );
   push @$operations,
-    Google::Ads::GoogleAds::V9::Services::AdGroupCriterionService::AdGroupCriterionOperation
+    Google::Ads::GoogleAds::V10::Services::AdGroupCriterionService::AdGroupCriterionOperation
     ->new({
       create => $ad_group_criterion_condition_new
     });
@@ -127,16 +127,16 @@ sub add_shopping_product_listing_group_tree {
     $customer_id,
     $ad_group_id,
     $ad_group_criterion_root_resource_name,
-    Google::Ads::GoogleAds::V9::Common::ListingDimensionInfo->new({
+    Google::Ads::GoogleAds::V10::Common::ListingDimensionInfo->new({
         productCondition =>
-          Google::Ads::GoogleAds::V9::Common::ProductConditionInfo->new({
+          Google::Ads::GoogleAds::V10::Common::ProductConditionInfo->new({
             condition => USED
           })}
     ),
     100000
   );
   push @$operations,
-    Google::Ads::GoogleAds::V9::Services::AdGroupCriterionService::AdGroupCriterionOperation
+    Google::Ads::GoogleAds::V10::Services::AdGroupCriterionService::AdGroupCriterionOperation
     ->new({
       create => $ad_group_criterion_condition_used
     });
@@ -147,13 +147,13 @@ sub add_shopping_product_listing_group_tree {
     $customer_id,
     $ad_group_id,
     $ad_group_criterion_root_resource_name,
-    Google::Ads::GoogleAds::V9::Common::ListingDimensionInfo->new({
+    Google::Ads::GoogleAds::V10::Common::ListingDimensionInfo->new({
         # All sibling nodes must have the same dimension type, even if they
         # don't contain a bid.
         productCondition =>
-          Google::Ads::GoogleAds::V9::Common::ProductConditionInfo->new()}));
+          Google::Ads::GoogleAds::V10::Common::ProductConditionInfo->new()}));
   push @$operations,
-    Google::Ads::GoogleAds::V9::Services::AdGroupCriterionService::AdGroupCriterionOperation
+    Google::Ads::GoogleAds::V10::Services::AdGroupCriterionService::AdGroupCriterionOperation
     ->new({
       create => $ad_group_criterion_condition_other
     });
@@ -174,15 +174,15 @@ sub add_shopping_product_listing_group_tree {
     $customer_id,
     $ad_group_id,
     $ad_group_criterion_condition_other_resource_name,
-    Google::Ads::GoogleAds::V9::Common::ListingDimensionInfo->new({
+    Google::Ads::GoogleAds::V10::Common::ListingDimensionInfo->new({
         productBrand =>
-          Google::Ads::GoogleAds::V9::Common::ProductBrandInfo->new(
+          Google::Ads::GoogleAds::V10::Common::ProductBrandInfo->new(
           {value => "CoolBrand"})}
     ),
     900000
   );
   push @$operations,
-    Google::Ads::GoogleAds::V9::Services::AdGroupCriterionService::AdGroupCriterionOperation
+    Google::Ads::GoogleAds::V10::Services::AdGroupCriterionService::AdGroupCriterionOperation
     ->new({
       create => $ad_group_criterion_brand_cool_brand
     });
@@ -194,15 +194,15 @@ sub add_shopping_product_listing_group_tree {
     $customer_id,
     $ad_group_id,
     $ad_group_criterion_condition_other_resource_name,
-    Google::Ads::GoogleAds::V9::Common::ListingDimensionInfo->new({
+    Google::Ads::GoogleAds::V10::Common::ListingDimensionInfo->new({
         productBrand =>
-          Google::Ads::GoogleAds::V9::Common::ProductBrandInfo->new(
+          Google::Ads::GoogleAds::V10::Common::ProductBrandInfo->new(
           {value => "CheapBrand"})}
     ),
     10000
   );
   push @$operations,
-    Google::Ads::GoogleAds::V9::Services::AdGroupCriterionService::AdGroupCriterionOperation
+    Google::Ads::GoogleAds::V10::Services::AdGroupCriterionService::AdGroupCriterionOperation
     ->new({
       create => $ad_group_criterion_brand_cheap_brand
     });
@@ -213,14 +213,14 @@ sub add_shopping_product_listing_group_tree {
     $customer_id,
     $ad_group_id,
     $ad_group_criterion_condition_other_resource_name,
-    Google::Ads::GoogleAds::V9::Common::ListingDimensionInfo->new({
+    Google::Ads::GoogleAds::V10::Common::ListingDimensionInfo->new({
         productBrand =>
-          Google::Ads::GoogleAds::V9::Common::ProductBrandInfo->new()}
+          Google::Ads::GoogleAds::V10::Common::ProductBrandInfo->new()}
     ),
     50000
   );
   push @$operations,
-    Google::Ads::GoogleAds::V9::Services::AdGroupCriterionService::AdGroupCriterionOperation
+    Google::Ads::GoogleAds::V10::Services::AdGroupCriterionService::AdGroupCriterionOperation
     ->new({
       create => $ad_group_criterion_brand_other_brand
     });
@@ -259,7 +259,7 @@ sub remove_listing_group_tree {
   # where the parent ad group criterion is NULL (and hence the root node in
   # the tree) for a given ad group id.
   my $search_request =
-    Google::Ads::GoogleAds::V9::Services::GoogleAdsService::SearchGoogleAdsRequest
+    Google::Ads::GoogleAds::V10::Services::GoogleAdsService::SearchGoogleAdsRequest
     ->new({
       customerId => $customer_id,
       query      => $search_query,
@@ -284,7 +284,7 @@ sub remove_listing_group_tree {
 
     # Create an ad group criterion operation.
     my $ad_group_criterion_operation =
-      Google::Ads::GoogleAds::V9::Services::AdGroupCriterionService::AdGroupCriterionOperation
+      Google::Ads::GoogleAds::V10::Services::AdGroupCriterionService::AdGroupCriterionOperation
       ->new({
         remove => $ad_group_criterion->{resourceName}});
 
@@ -313,7 +313,7 @@ sub create_listing_group_subdivision {
     = @_;
 
   my $listing_group_info =
-    Google::Ads::GoogleAds::V9::Common::ListingGroupInfo->new({
+    Google::Ads::GoogleAds::V10::Common::ListingGroupInfo->new({
       # Set the type as a SUBDIVISION, which will allow the node to be the
       # parent of another sub-tree.
       'type' => SUBDIVISION
@@ -332,11 +332,11 @@ sub create_listing_group_subdivision {
   }
 
   my $ad_group_criterion =
-    Google::Ads::GoogleAds::V9::Resources::AdGroupCriterion->new({
+    Google::Ads::GoogleAds::V10::Resources::AdGroupCriterion->new({
       # The resource name the criterion will be created with. This will define
       # the ID for the ad group criterion.
       resourceName =>
-        Google::Ads::GoogleAds::V9::Utils::ResourceNames::ad_group_criterion(
+        Google::Ads::GoogleAds::V10::Utils::ResourceNames::ad_group_criterion(
         $customer_id, $ad_group_id, next_id()
         ),
       status       => ENABLED,
@@ -361,13 +361,13 @@ sub create_listing_group_unit_biddable {
   # the listing group for non-root nodes.
   # This example demonstrates method (1).
   my $ad_group_criterion =
-    Google::Ads::GoogleAds::V9::Resources::AdGroupCriterion->new({
-      adGroup => Google::Ads::GoogleAds::V9::Utils::ResourceNames::ad_group(
+    Google::Ads::GoogleAds::V10::Resources::AdGroupCriterion->new({
+      adGroup => Google::Ads::GoogleAds::V10::Utils::ResourceNames::ad_group(
         $customer_id, $ad_group_id
       ),
       status       => ENABLED,
-      listingGroup => Google::Ads::GoogleAds::V9::Common::ListingGroupInfo->new(
-        {
+      listingGroup =>
+        Google::Ads::GoogleAds::V10::Common::ListingGroupInfo->new({
           # Set the type as a UNIT, which will allow the group to be biddable.
           type => UNIT,
           # Set the ad group criterion resource name for the parent listing group.
@@ -376,7 +376,7 @@ sub create_listing_group_unit_biddable {
           # Case values contain the listing dimension used for the node.
           caseValue => $listing_dimension_info
         }
-      ),
+        ),
       # Set the bid for this listing group unit.
       # This will be used as the CPC bid for items that are included in this
       # listing group.
